@@ -1,4 +1,4 @@
-;;;; -*- Mode: Lisp; indent-tabs-mode: nil -*-
+;;;; -*- Mode: LISP; Syntax: Ansi-Common-Lisp; Package: FIVEAM; Base: 10; -*-
 
 (in-package :it.bese.fiveam)
 
@@ -130,7 +130,8 @@ If PROFILE is T profiling information will be collected as well."
                                  (:definition-time body))))
                          :description description
                          :depends-on depends-on
-                         :collect-profiling-info profile))
+                         :collect-profiling-info profile
+                         :test-suite suite))
     (setf (gethash name (tests suite)) name)))
 
 (defvar *run-test-when-defined* nil
